.. _reference_tensor_discrete_fourier:

Discrete Fourier Transform
==========================

``aesara.tensor.fourier``
~~~~~~~~~~~~~~~~~~~~~~~~~

.. note::

   You need to import the ``aesara.tensor.fourier`` module first.


.. currentmodule:: aesara.tensor.fourier
.. autosummary::
   :toctree: _autosummary

   fft


``aesara.tensor.fft``
~~~~~~~~~~~~~~~~~~~~~~

.. note::

   You need to import the ``aesara.tensor.fft`` module first.


.. currentmodule:: aesara.tensor.fft
.. autosummary::
   :toctree: _autosummary

   rfft
   irfft
